@@ -6,8 +6,9 @@ from django.conf import settings
 from helpers import get_model
 
 class ManyToManyWidget(Widget):
-    def __init__(self, model_str, **kwargs):
+    def __init__(self, model_str, search_field, **kwargs):
         self.model_str = model_str
+        self.search_field = search_field
         return super(self.__class__, self).__init__(**kwargs)
 
     def value_from_datadict(self, data, files, name):
@@ -26,16 +27,19 @@ class ManyToManyWidget(Widget):
             "name": name,
             "value": ",".join(value),
             "model_str": self.model_str,
+            "field": self.search_field,
         }))
 
 class SelectWidget(Widget):
-    def __init__(self, model_str, **kwargs):
+    def __init__(self, model_str, search_field, **kwargs):
         self.model_str = model_str
+        self.search_field = search_field
         return super(SelectWidget, self).__init__(**kwargs)
 
     def render(self, name, value, attrs=None):
         if value and value != "None":
-            text_value = get_model(self.model_str).objects.get(pk=value).__unicode__()
+            obj = get_model(self.model_str).objects.get(pk=value)
+            text_value = "%s #%s" % (getattr(obj, self.search_field), obj.pk)
         else:
             text_value = ""
             value = ""
@@ -46,4 +50,5 @@ class SelectWidget(Widget):
             "value": value,
             "text_value": text_value,
             "model_str": self.model_str,
+            "field": self.search_field,
         }))
